export class Inventory
{
	constructor(){
		this.items = new Map();
		this.maxStacks = 12;
	}

	add(id, data){
		if(this.items.has(id)){
			return this._addExsitingItem(id);
		} else {
			return this._addNewItem(id, data)
		}
	}
	
	_addNewItem(id, data) {
		const canAdd = this.canAddItems(id);
	
		if(canAdd){
			this.items.set(id, {
				count: 1,
				stackSize: data.stackSize,
				stacks: 1
			});
		}
		
		return canAdd;
	}
	
	
	_addExsitingItem(id) {
		const canAdd = this.canAddItems(id);
		
		if(canAdd){
			const i = this.items.get(id);
			i.count += 1;
			i.stacks = Math.ceil(i.count / i.stackSize);
		}
		
		return canAdd;
	}
	
	
	canAddItems(id) {
		if(this.items.has(id)){
			const i = this.items.get(id);
			const size = i.stacks * i.stackSize;
			
			if(i.count+1 <= size){
				return true;
			}
		}
	
		if(this.getStackCount() < this.maxStacks){
			return true;
		}
		
		return false;
	}
	
	getStackCount() {
		let stack = 0;
		if(this.items.size > 0){
			for(const item of this.items.values()){
				stack += item.stacks;
			}
		}
		 return stack;
	}
	
	
	getAllItems() {
		const result= [];
		
		for(const item of this.items.entries()){
			
			let count =item[1].count;
			const stackSize = item[1].stackSize;
			let stacks = item[1].stacks;
			
			
			while(stacks > 0){
				
				const itemCount = (count-stackSize < 0) ? count : stackSize;
				
				result.push({
					id: item[0],
					count: itemCount
				});
				
				count -= stackSize;
				stacks--;
			}
			
		}
		
		//populate empty objects
		while(result.length < this.maxStacks){
			result.push({
				id: "null",
				count: 0
			});
		}
		
		return result;
	}
	
	hasItem(itemID, count){
		const item = this.items.get(itemID);
		if(item){
			return item.count >= count;
		}
		return false;
	}
	
	removeItem(itemID, count) {
		const item = this.items.get(itemID);
		item.count -= count;
		item.stacks = Math.ceil(item.count / item.stackSize);
		
		if(item.count <= 0) {
			this.items.delete(itemID);
		}
	}	
	
}