import {Utils} from "./utils.js";

export class PlayerManager extends ISpriteInstance
{
	constructor()
	{
		super();
		
		this.maxHealth = 6; //assume max is even
		this.currentHealth = 6;
		
		this.equippedItem = null;
		
		this.itemSlots = [];
		this.maxItemsSlots = 5;
	}
	
	drawHealth(placeHolder) {
		const heartClass = this.runtime.objects.heart;
		const heartWidth = placeHolder.width;
		let heartX = placeHolder.x;
		let heartY = placeHolder.y;
		
		//how many hearts
		const fullHearts = Math.floor(this.currentHealth / 2);
		const partialHearts = this.currentHealth % 2;
		const emptyHearts = (this.maxHealth / 2) - (fullHearts + partialHearts);
		
		//draw hearts
		for(let i=0; i< fullHearts; i++){
			const heart = heartClass.createInstance('menu', heartX, heartY, false);
			heart.setAnimation("2");
			heartX += heartWidth + 3;
			this.attach(heart);
		}
		
		for(let i=0; i< partialHearts; i++){
			const heart = heartClass.createInstance('menu', heartX, heartY, false);
			heart.setAnimation("1");
			heartX += heartWidth + 3;
			this.attach(heart);
		}
		
		for(let i=0; i< emptyHearts; i++){
			const heart = heartClass.createInstance('menu', heartX, heartY, false);
			heart.setAnimation("0");
			heartX += heartWidth + 3;
			this.attach(heart);
		}
	}
	
	drawEquipment(){
		const heldItemButtonClass = this.runtime.objects.heldItemButton;
		const equipmentButtonClass = this.runtime.objects.equipmentButton;
		
		let startX = this.x;
		let startY = this.y;
		let buttonWidth = this.width + 3
		
		//draw held item button
		const heldItem = heldItemButtonClass.createInstance('menu', startX, startY, false);
		if(this.equippedItem){
			const icon = Utils.createIcon(this.equippedItem, 'menu', heldItem.x, heldItem.y+7, heldItem);
			heldItem.instVars.itemID = this.equippedItem;
			this.attach(heldItem);
		}
	}
	
	attach(child){
		this.addChild(child, {
			"transformX": true,
			"transformY" : true,
			"destroyWithParent" : true
		});
	}
}